"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Get a value indicating where the cursor is inside a rectangle:
 *
 * @param rectangle The rectangle
 * @param mouseCoordinates The mouse coordinates
 *
 * @returns
 * - `above` if the cursor is in the upper part of the rectangle (above its middle line)
 * - `below` if the cursor is in the lower part of the rectangle (below its middle line)
 * - `over` if the cursor is in the middle part of the rectangle
 * - `none` if the cursor is not over the rectangle
 */
var getMousePosition = function (rectangle, mouseCoordinates) {
    // Get vertical middle
    var hoverMiddleY = (rectangle.bottom - rectangle.top) / 2;
    // Get pixels to the top
    var hoverClientY = mouseCoordinates.y - rectangle.top;
    var percentage = (hoverMiddleY - hoverClientY) / rectangle.height;
    var isAbove = percentage > 0.25;
    var isBelow = percentage < -0.25;
    return isAbove ? 'above' : isBelow ? 'below' : 'over';
};
exports.default = getMousePosition;
